@@ -402,7 +402,8 @@ class TestBuildCli:
     def test_build_show_logs(self, mocker, monkeypatch, tuxsuite_config):
         Build = mocker.patch("tuxsuite.Build")
         build = Build.return_value
-        build.build_data = "https://builds.com/21321312312/"
+        build.status = {}
+        build.status["download_url"] = "https://builds.com/21321312312/"
         download_file = mocker.patch("tuxsuite.download.download_file")
         monkeypatch.setattr(
             sys,
@@ -1221,7 +1222,8 @@ class TestResultsCli:
 
         mocker.resetall()
         results = mocker.patch(
-            "tuxsuite.Results.get_build", return_value=sample_build_result
+            "tuxsuite.Results.get_build",
+            return_value=(sample_build_result, "http://api"),
         )
         monkeypatch.setattr(
             sys,
@@ -1288,7 +1290,8 @@ class TestResultsCli:
 
         mocker.resetall()
         results = mocker.patch(
-            "tuxsuite.Results.get_oebuild", return_value=sample_oebuild_result
+            "tuxsuite.Results.get_oebuild",
+            return_value=(sample_oebuild_result, "http://api"),
         )
         monkeypatch.setattr(
             sys,
@@ -1305,7 +1308,8 @@ class TestResultsCli:
 
         mocker.resetall()
         results = mocker.patch(
-            "tuxsuite.Results.get_build", return_value=sample_build_result
+            "tuxsuite.Results.get_build",
+            return_value=(sample_build_result, "http://api"),
         )
         monkeypatch.setattr(
             sys,
@@ -1321,7 +1325,8 @@ class TestResultsCli:
 
         mocker.resetall()
         results = mocker.patch(
-            "tuxsuite.Results.get_oebuild", return_value=sample_oebuild_result
+            "tuxsuite.Results.get_oebuild",
+            return_value=(sample_oebuild_result, "http://api"),
         )
         monkeypatch.setattr(
             sys,
@@ -1381,7 +1386,7 @@ class TestResultsCli:
         mocker.resetall()
         results = mocker.patch(
             "tuxsuite.Results.get_build",
-            return_value=sample_build_result,
+            return_value=(sample_build_result, "http://api"),
             side_effect=tuxsuite.exceptions.URLNotFound,
         )
         monkeypatch.setattr(
