@@ -5,7 +5,7 @@
 This is the tuxsuite module.
 """
 
-__version__ = "1.0.3"
+__version__ = "1.1.0"
 
 
 from . import build
@@ -182,7 +182,7 @@ class BuildPlan(PlanType):
             ret = build.post_request(f"{plan.url}/builds", plan.headers, req_data)
             # Updating builds_to_submit will update values in builds
             for (build_obj, data) in zip(builds_to_submit, ret):
-                build_obj.build_data = data["download_url"]
+                build_obj.build_data = f"{plan.url}/builds/{data['uid']}"
                 build_obj.uid = data["uid"]
                 build_obj.status = data
 
@@ -253,6 +253,6 @@ class BakePlan(PlanType):
             ret = build.post_request(f"{plan.url}/oebuilds", plan.headers, req_data)
             # Updating builds_to_submit will update values in builds
             for (bake_obj, data) in zip(builds_to_submit, ret):
-                bake_obj.build_data = data["download_url"]
+                bake_obj.build_data = f"{plan.url}/oebuilds/{data['uid']}"
                 bake_obj.uid = data["uid"]
                 bake_obj.status = data
