@@ -34,7 +34,7 @@ def post_request(url, headers, request):
     if response.ok:
         return json.loads(response.text)
     else:
-        if response.status_code == 400:
+        if response.status_code in [400, 403]:
             response_data = response.json()
             if "error" in response_data:
                 message = response_data["error"]
@@ -306,8 +306,8 @@ class Build(HeadersMixin):
             self.group, self.project
         )
         self.status = post_request(url, self.headers, data)[0]
-        self.build_data = self.status["download_url"]
         self.uid = self.status["uid"]
+        self.build_data = f"{url}/{self.uid}"
 
     def get_status(self):
         """Fetches the build status and updates the values inside the build object"""
@@ -993,7 +993,8 @@ class Results(HeadersMixin):
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}/builds/{}".format(
             self.group, self.project, self.uid
         )
-        return get_request(url, self.headers)
+        result = get_request(url, self.headers)
+        return (result, url)
 
     def get_test(self):
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}/tests/{}".format(
@@ -1006,7 +1007,8 @@ class Results(HeadersMixin):
         url = self.tuxapi_url + "/v1/groups/{}/projects/{}/oebuilds/{}".format(
             self.group, self.project, self.uid
         )
-        return get_request(url, self.headers)
+        result = get_request(url, self.headers)
+        return (result, url)
 
     def get_plan(self):
         plan = Plan(
@@ -1018,8 +1020,8 @@ class Results(HeadersMixin):
             plan=self.uid,
         )
         # TODO: Return the test url as part of the test result in tuxapi
-        tuxapi_tests_url = plan.url + "/tests"
-        return (plan.get_plan(), tuxapi_tests_url)
+        tuxapi_url = plan.url
+        return (plan.get_plan(), tuxapi_url)
 
     def get_all(self):
         all_results = {}
@@ -1032,8 +1034,7 @@ class Results(HeadersMixin):
             type_url = url + f"/{res_type}"
             all_results[res_type] = get_request(type_url, self.headers)
 
-        test_url = url + "/tests"
-        return (all_results, test_url)
+        return (all_results, url)
 
 
 @attrs(kw_only=True, order=False)
@@ -1120,8 +1121,8 @@ class Bitbake(HeadersMixin):
             self.group, self.project
         )
         self.status = post_request(url, self.headers, data)
-        self.build_data = self.status["download_url"]
         self.uid = self.status["uid"]
+        self.build_data = f"{url}/{self.uid}"
 
     def get_status(self):
         """Fetches the build status and updates the values inside the build object"""
