@@ -18,7 +18,7 @@ LIMIT = 50
 
 
 def error(msg):
-    sys.stderr.write(f"Error: {msg}")
+    sys.stderr.write(f"Error: {msg}\n")
     sys.exit(1)
 
 
@@ -83,10 +83,10 @@ def print_state(state, prefix=""):
         print(msg)  # info(msg)
 
 
-def format_result(result_json, tuxapi_tests_url=None, prefix=""):
+def format_result(result_json, tuxapi_url=None, prefix=""):
     state = result_states.get(result_json["state"], None)
     result = result_json["result"]
-    result_msg = get_result_msg(result_json, tuxapi_tests_url)
+    result_msg = get_result_msg(result_json, tuxapi_url)
     if state is None:
         errors = 0
         warnings = 0
@@ -141,7 +141,7 @@ def format_result(result_json, tuxapi_tests_url=None, prefix=""):
         print(msg)  # info(msg)
 
 
-def get_result_msg(result_json, tuxapi_tests_url):
+def get_result_msg(result_json, tuxapi_url):
     result_msg = ""
     if "build_name" in result_json:
         if (
@@ -152,7 +152,7 @@ def get_result_msg(result_json, tuxapi_tests_url):
             result_msg = (
                 f"{result_json['target_arch']} "
                 f"({','.join(result_json['kconfig'])}) "
-                f"with {result_json['toolchain']} @ {result_json['download_url']}"
+                f"with {result_json['toolchain']} @ {tuxapi_url}"
             )
     elif "sources" in result_json:
         if (
@@ -166,18 +166,18 @@ def get_result_msg(result_json, tuxapi_tests_url):
             result_msg = (
                 f"with container: {result_json['container']}, "
                 f"machine: {result_json['machine']} and "
-                f"targets: {result_json['targets']}  @ {result_json['download_url']}"
+                f"targets: {result_json['targets']}  @ {tuxapi_url}"
             )
         elif result_json["sources"].get("kas") and result_json.get("container"):
             result_msg = (
                 f"with container: {result_json['container']}, "
-                f"kas: {result_json['sources']['kas']} @ {result_json['download_url']}"
+                f"kas: {result_json['sources']['kas']} @ {tuxapi_url}"
             )
 
     elif "tests" in result_json:
         result_msg = (
             f"[{','.join(result_json['tests'])}] "
-            f"{result_json['device']} @ {tuxapi_tests_url}"
+            f"{result_json['device']} @ {tuxapi_url}"
         )
     return result_msg
 
@@ -192,7 +192,7 @@ def show_log(build, download, output_dir):
             print(line.strip(), file=sys.stderr)
     else:
         tuxsuite.download.download_file(
-            os.path.join(build.build_data, "build.log"), sys.stderr.buffer
+            os.path.join(build.status["download_url"], "build.log"), sys.stderr.buffer
         )
 
 
